Stan Math Library: stan/math/prim/scal/err/check_nonnegative.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

check_nonnegative.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_ERR_CHECK_NONNEGATIVE_HPP
2 #define STAN_MATH_PRIM_SCAL_ERR_CHECK_NONNEGATIVE_HPP
3
4 #include <stan/math/prim/scal/err/domain_error.hpp>
5 #include <stan/math/prim/scal/err/domain_error_vec.hpp>
6 #include <stan/math/prim/scal/meta/length.hpp>
7 #include <stan/math/prim/scal/meta/value_type.hpp>
8 #include <stan/math/prim/scal/meta/is_vector_like.hpp>
9 #include <boost/type_traits/is_unsigned.hpp>
10
11 namespace stan {
12
13 namespace math {
14
15 namespace {
16 template <typename T_y, bool is_vec>
17 struct nonnegative {
18 static bool check(const char* function,
19 const char* name,
20 const T_y& y) {
21 // have to use not is_unsigned. is_signed will be false
22 // floating point types that have no unsigned versions.
23 if (!boost::is_unsigned<T_y>::value && !(y >= 0))
24 domain_error(function, name, y,
25 "is ", ", but must be >= 0!");
26 return true;
27 }
28 };
29
30 template <typename T_y>
31 struct nonnegative<T_y, true> {
32 static bool check(const char* function,
33 const char* name,
34 const T_y& y) {
35 using stan::length;
36 using stan::math::value_type;
37
38 for (size_t n = 0; n < length(y); n++) {
39 if (!boost::is_unsigned<typename value_type<T_y>::type>::value
40 && !(stan::get(y, n) >= 0))
41 domain_error_vec(function, name, y, n,
42 "is ", ", but must be >= 0!");
43 }
44 return true;
45 }
46 };
47 }
48
65 template <typename T_y>
66 inline bool check_nonnegative(const char* function,
67 const char* name,
68 const T_y& y) {
69 return nonnegative<T_y, is_vector_like<T_y>::value>
70 ::check(function, name, y);
71 }
72 }
73 }
74 #endif
stan
Definition: log_sum_exp.hpp:8
stan::length
size_t length(const std::vector< T > &x)
Definition: length.hpp:10
domain_error_vec.hpp
is_vector_like.hpp
stan::math::domain_error_vec
void domain_error_vec(const char *function, const char *name, const T &y, const size_t i, const char *msg1, const char *msg2)
Throw a domain error with a consistently formatted message.
Definition: domain_error_vec.hpp:38
stan::get
T get(const std::vector< T > &x, size_t n)
Definition: get.hpp:10
stan::math::domain_error
void domain_error(const char *function, const char *name, const T &y, const char *msg1, const char *msg2)
Throw a domain error with a consistently formatted message.
Definition: domain_error.hpp:32
length.hpp
value_type.hpp
domain_error.hpp
stan::math::check_nonnegative
bool check_nonnegative(const char *function, const char *name, const T_y &y)
Return true if y is non-negative.
Definition: check_nonnegative.hpp:66
stan::math::value_type
Primary template class for metaprogram to compute the type of values stored in a container.
Definition: value_type.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.